==> libdcp-1.3.4.tar.bz2: libdcp-1.3.4/src/asset_reader.h <==
/*
    Copyright (C) 2016 Carl Hetherington <cth@carlh.net>

    This file is part of libdcp.

    libdcp is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    libdcp is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with libdcp.  If not, see <http://www.gnu.org/licenses/>.

    In addition, as a special exception, the copyright holders give
    permission to link the code of portions of this program with the
    OpenSSL library under certain conditions as described in each
    individual source file, and distribute linked combinations
    including the two.

    You must obey the GNU General Public License in all respects
    for all of the code used other than OpenSSL.  If you modify
    file(s) with this exception, you may extend this exception to your
    version of the file(s), but you are not obligated to do so.  If you
    do not wish to do so, delete this exception statement from your
    version.  If you delete this exception statement from all source
    files in the program, then also delete it here.
*/

#ifndef LIBDCP_ASSET_READER_H
#define LIBDCP_ASSET_READER_H

#include <boost/noncopyable.hpp>

namespace ASDCP {
	class AESDecContext;
}

namespace dcp {

class MXF;

class AssetReader : public boost::noncopyable
{
public:
	explicit AssetReader (MXF const * mxf);
	virtual ~AssetReader ();

protected:
	ASDCP::AESDecContext* _decryption_context;
};

}

#endif

==> libdcp-1.5.2.tar.bz2: libdcp-1.5.2/src/asset_reader.h <==
/*
    Copyright (C) 2016 Carl Hetherington <cth@carlh.net>

    This file is part of libdcp.

    libdcp is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    libdcp is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with libdcp.  If not, see <http://www.gnu.org/licenses/>.

    In addition, as a special exception, the copyright holders give
    permission to link the code of portions of this program with the
    OpenSSL library under certain conditions as described in each
    individual source file, and distribute linked combinations
    including the two.

    You must obey the GNU General Public License in all respects
    for all of the code used other than OpenSSL.  If you modify
    file(s) with this exception, you may extend this exception to your
    version of the file(s), but you are not obligated to do so.  If you
    do not wish to do so, delete this exception statement from your
    version.  If you delete this exception statement from all source
    files in the program, then also delete it here.
*/

#ifndef LIBDCP_ASSET_READER_H
#define LIBDCP_ASSET_READER_H

#include "dcp_assert.h"
#include "asset.h"
#include "decryption_context.h"
#include <asdcp/AS_DCP.h>
#include <boost/noncopyable.hpp>
#include <boost/shared_ptr.hpp>

namespace dcp {

class DecryptionContext;

template <class R, class F>
class AssetReader : public boost::noncopyable
{
public:
	explicit AssetReader (Asset const * asset, boost::optional<Key> key)
		: _decryption_context (new DecryptionContext (key))
	{
		_reader = new R ();
		DCP_ASSERT (asset->file ());
		Kumu::Result_t const r = _reader->OpenRead (asset->file()->string().c_str());
		if (ASDCP_FAILURE (r)) {
			delete _reader;
			boost::throw_exception (FileError ("could not open MXF file for reading", asset->file().get(), r));
		}
	}

	~AssetReader ()
	{
		delete _reader;
	}

	boost::shared_ptr<const F> get_frame (int n) const
	{
		return boost::shared_ptr<const F> (new F (_reader, n, _decryption_context));
	}

protected:
	R* _reader;
	boost::shared_ptr<DecryptionContext> _decryption_context;
};

}

#endif
